import RedisClient from './lib/client';
import RedisCluster from './lib/cluster';

export { RedisClientType, RedisClientOptions } from './lib/client';

export { RedisModules, RedisFunctions, RedisScripts } from './lib/commands';

export const createClient = RedisClient.create;

export const commandOptions = RedisClient.commandOptions;

export { RedisClusterType, RedisClusterOptions } from './lib/cluster';

export const createCluster = RedisCluster.create;

export { defineScript } from './lib/lua-script';

export { GeoReplyWith } from './lib/commands/generic-transformers';

export * from './lib/errors';

export { SetOptions } from "./lib/commands/SET";
